function [v5d_output, iaxis, jaxis, rx, ry]=v5darbzslice(v5dstruc,var,time,xV,yV,res);
%V5DArbZSLICE - read a Z slice with an arbirary rotation in the XY plane
%
%  [SLICE, ARBAXIS, ZAXIS, XCOORD, YCOORD] = 
%                     V5DArbZSLICE(V5DINFO, nVARIABLE, nT, Xp, Yp, SPACING);
%
%  V5DINFO is the structure returned from opening a Vis5D file, nVARIABLE is
%  the variable index, nT is the time index.  the points (Xp(1),Yp(1)) and
%  (Xp(2),Yp(2)) are the end points of the line defining the slice on XY.
%  SPACING is the desired spacing between points on the arbitrary axis, given
%  in the same units as the XY grid.
%
%  SLICE is the two-dimensional interpolated grid, ARBAXIS is the labels for
%  the arbitrary axis starting at 0 from (Xp(1),Yp(1)) incrementing by res. 
%  XCOORD and YCOORD are the actual coordinates of points on the arbitrary
%  axis
%
%  See also: VIS5D

jaxis=v5dstruc.vars(var).zaxis;

angle=atan2(yV(1)-yV(2),xV(1)-xV(2));
dy=res*sin(angle);
dx=res*cos(angle);

ry=(yV(1):-dy:yV(2));
rx=(xV(1):-dx:xV(2));
iaxis=(0:res:res*(prod(size(ry))-1));

vol=v5dvol(var,time);

v5d_output=zeros(prod(size(rx)),v5dstruc.vars(var).zdim);
%size(v5d_output)

for z=1:v5dstruc.vars(var).zdim,
  v5d_output(:,z)=transpose(interp2(v5dstruc.yaxis,v5dstruc.xaxis,vol(:,:,z),ry,rx));
%  size(interp2(v5dstruc.xaxis,v5dstruc.yaxis,vol(:,:,z),rx,ry))
end
