function [profile,x]=v5davexprofile(v5dstruc,var,z,t,fig_num);
% [profile,x]=v5davexprofile(v5dstruc,var,z,t,fig_num);
%produces x-profile of 'var' averaged over a north-south slice at altitude, z
%for time, t.
% profile  = mean  profile of variable.
% v5dstruc = vis5d structure returned by vis5d('open', filename).
% var      = string containing name of a variable in the v5dstruc(eg. 'THETA').
% x        = z-location of profile.
% t        = time string for desired value. This may be specified by
%              time frame number (a number <1000) or as a matlab date 
%              string (eg.'01-Mar-1995 15:45:17') If only the time is specified
%              (eg. 15:45) the date is set to the start date specified in the 
%              v5d structure file.
% fig_num = figure number for plot--suppress figure if fig_num=0;


currentfile=vis5d('file');
if (strcmp(currentfile,v5dstruc.filename) ~= 1)
  vis5d('open',v5dstruc.filename);
end;

xyza=[0,0,z];
[nvar,nxyzt,xyz,t]=v5dlocate(v5dstruc, var,xyza,t);	
xyslice = v5dxyslice(nvar, nxyzt(3), nxyzt(4));
[jnk,nypoints]=size(xyslice);
profile=sum(xyslice,2)/nypoints;
x=v5dstruc.xaxis;
if fig_num >0
   figure(fig_num);
   plot(v5dstruc.xaxis,profile)
   ylabel([v5dstruc.vars(nvar).name,' ',v5dstruc.vars(nvar).units])
   xlabel('X-distance (km)')
   tstring=['Y-averaged ',v5dstruc.vars(nvar).name,' vs x-distance at z= '];
   tstring=[tstring, num2str(xyz(3)),' km    ',v5dstruc.times(nxyzt(4),:)];
   title(tstring);
   grid
end;