function [profile,z]=v5davezprofile(v5dstruc,var,x,t,fig_num);
%function [profile,z]=v5davezprofile(v5dstruc,var,x,t,fig_num);
% Makes a y-averaged vertical profile of 'var' at location, x, for time, t.
% profile  = y-averaged vertical profile of variable.
% v5dstruc = vis5d structure returned by vis5d('open', filename).
% var      = string containing name of a variable in the v5dstruc(eg. 'THETA').
% x        = x-location of profile.
% t        = time. This may be specified by
%              time frame number (a number <1000) or as a matlab date 
%              string (eg.'01-Mar-1995 15:45:17') If only the time is specified
%              (eg. 15:45 or 15:45:17) the date is set to the start date 
%              specified in the v5d file.
% fig_num = figure number for plot--suppress figure if fig_num=0;



currentfile=vis5d('file');
if (strcmp(currentfile,v5dstruc.filename) ~= 1)
    vis5d('open',v5dstruc.filename);
end;
xyza=[x,0,0];
[nvar,nxyzt,xyz,t]=v5dlocate(v5dstruc, var,xyza,t);
z=v5dstruc.vars(nvar).zaxis;	
yzslice = v5dyzslice(nvar, nxyzt(1), nxyzt(4));
[nypoints,jnk]=size(yzslice);
profile=sum(yzslice,1)/nypoints;
if fig_num > 0
   figure(fig_num);
   plot(profile,z) 
   xlabel([v5dstruc.vars(nvar).name, ' ',v5dstruc.vars(nvar).units])
   ylabel(['Altitude (',v5dstruc.xyzunits.x,')'])
   tstring=['Y-averaged ',v5dstruc.vars(nvar).name,' vs Altitude at x= ']
   tstring=[tstring,num2str(xyz(1)),' km    ',v5dstruc.times(nxyzt(4),:)]
   title(tstring);
   grid
end;