function [xyslice,xaxis,yaxis,z,t]=v5dplotxyslice(v5dstruc,varstr,xylimits,za,ta,fig_num);
%[xyslice,xaxis,yaxis,z,t]=v5dplotxyslice(v5dstruc,varstr,xylimits,za,ta,fig_num)
% v5dplotxyslice produces a horizontal cross section of the variable specified
%    in the variable string 'varstr' at a selected altitude and time. 
% v5dstruc = vis5d structure from v5dstruc=vis5d('open','vis5dfilename')
% varstr   = a string giving the name of the variable to plot (eg 'U')
%            this string must be one of the names specified 
%            in v5dstruc.vars.name
% xylimits = vector giving limits of plot, [xlo xhi ylo yhi]
% za       = Altitude of slice.   
% ta       = time specified as frame number, full matlab date string or
%            time of day '15:46:39' with date from v5dstruc start time.
% fig_num   = Save ppm versions of the figures
%            where f# is the time frame number.
%            If ppmstr =' ' no *.ppm files will be saved.

currentfile=vis5d('file');
if (strcmp(currentfile,v5dstruc.filename) ~= 1)
  vis5d('open',v5dstruc.filename);
end;


%get lower limits 
xyza=[xylimits(1) xylimits(3) za];
[nvar,nxyzt,xyz,t]=v5dlocate(v5dstruc, varstr, xyza, ta);
xlo=xyz(1);
ylo=xyz(2);
z=xyz(3);
nxlo=nxyzt(1);
nyhi=nxyzt(2);


%get upper limits
xyza=[xylimits(2) xylimits(4) za];
[nvar,nxyzt,xyz,t]=v5dlocate(v5dstruc, varstr, xyza, ta);
xhi=xyz(1);
yhi=xyz(2);
nxhi=nxyzt(1);
nylo=nxyzt(2);


%get full xy slice
[fullslice] = v5dxyslice(nvar,nxyzt(3), nxyzt(4));
xyslice=fullslice(nxlo:nxhi,nylo:nyhi);
t=v5dstruc.times(nxyzt(4),:);


xaxis=v5dstruc.xaxis(nxlo:nxhi);
yaxis=v5dstruc.yaxis(nylo:nyhi);

if fig_num>0
  figure(fig_num);
  %colormap gray;
  h1=imagesc(xyslice','XData',[xlo xhi],'YData',[ yhi ylo]);
          %set(gca, 'Clim', [5 15])  %set speed scale 5-> 15 m/sec
 
  axis image;          %make square pixels
  set(gca,'YDir','normal')
  colorbar;
  if strcmp(v5dstruc.xyzunits.x,'')~=1
     xustr=['(',v5dstruc.xyzunits.x,')']; %compose x-units string if present.
  else
     xustr='';   
  end;
  if strcmp(v5dstruc.xyzunits.y,'')~=1
     yustr=['(',v5dstruc.xyzunits.y,')']; %compose y-units string if present.
  else
     yustr='';   
  end; 
  if strcmp(v5dstruc.vars(nvar).units,'')~=1
     vustr=['(',v5dstruc.vars(nvar).units,')']; %compose var-units string if present.
  else
     vustr='';   
  end;

  xlabel(['X-distance ',xustr])
  ylabel(['Y-distance ',yustr])
  title([v5dstruc.vars(nvar).name,' ',vustr,' at z=' num2str(xyz(3)*1000),'m   ',v5dstruc.times(nxyzt(4),:)]);
   %if ppmflg == 1
   %   FNumbStr=sprintf('%02d',nxyzt(4));
   %   filename=['speed_',ppmstr,FNumbStr,'.ppm'] 
   %   print( '-dppmraw', filename)
   %end;
end;
 






