function [xzslice,xaxis,zaxis,y,t]=v5dplotxzslice(v5dstruc,varstr,xzlimits,ya,ta,fig_num);
%[xzslice,xaxis,zaxis,y,t]=v5dplotxzslice(v5dstruc,varstr,xzlimits,ya,ta,fig_num)
% v5dplotxzslice produces a vertical cross section of the variable specified
%    in the variable string 'varstr' at a selected altitude and time. 
% v5dstruc = vis5d structure from v5dstruc=vis5d('open','vis5dfilename')
% varstr   = a string giving the name of the variable to plot (eg 'U')
%            this string must be one of the names specified 
%            in v5dstruc.vars.name
% xzlimits = vector giving limits of plot, [xlo xhi zlo zhi]
% ya       = y-position of slice.   
% ta       = time specified as frame number, full matlab date string or
%            time of day '15:46:39' with date from v5dstruc start time.
% fig_num   = Save ppm versions of the figures
%            where f# is the time frame number.


currentfile=vis5d('file');
if (strcmp(currentfile,v5dstruc.filename) ~= 1)
  vs5dstruc=vis5d('open',v5dstruc.filename);
end;


%get lower limits 
xyza=[xzlimits(1) ya xzlimits(3)];
[nvar,nxyzt,xyz,t]=v5dlocate(v5dstruc, varstr, xyza, ta);
xlo=xyz(1);
zlo=xyz(3);
y=xyz(2);
nxlo=nxyzt(1);
nzlo=nxyzt(3);

%get upper limits
xyza=[xzlimits(2) ya xzlimits(4)];
[nvar,nxyzt,xyz,t]=v5dlocate(v5dstruc, varstr, xyza, ta);
xhi=xyz(1);
zhi=xyz(3);
nxhi=nxyzt(1);
nzhi=nxyzt(3);
%get full xy slice
[fullslice] = v5dxzslice(nvar,nxyzt(2), nxyzt(4));
xzslice=fullslice(nxlo:nxhi,nzlo:nzhi);
t=v5dstruc.times(nxyzt(4),:);
xaxis=v5dstruc.xaxis(nxlo:nxhi);
zaxis=v5dstruc.vars(nvar).zaxis(nzlo:nzhi);

if fig_num>0
  figure(fig_num);
  %colormap gray;
  h1=imagesc(xzslice','XData',[xlo xhi],'YData',[zlo zhi]);
  set(gca,'YDir','normal')
  axis image;          %make square pixels
  colorbar;
  grid

if strcmp(v5dstruc.xyzunits.x,'')~=1
     xustr=['(',v5dstruc.xyzunits.x,')']; %compose x-units string if present.
  else
     xustr='';   
  end;
  if strcmp(v5dstruc.xyzunits.z,'')~=1
     zustr=['(',v5dstruc.xyzunits.z,')']; %compose y-units string if present.
  else
     zustr='';   
  end; 
  if strcmp(v5dstruc.vars(nvar).units,'')~=1
     vustr=['(',v5dstruc.vars(nvar).units,')']; %compose var-units string 
  else
     vustr='';   
  end;

  xlabel(['X-distance ',xustr]);
  ylabel(['Altitude ',zustr]);
  title([v5dstruc.vars(nvar).name, vustr,' at y=' num2str(xyz(2)),' (',v5dstruc.xyzunits.y,')   ',v5dstruc.times(nxyzt(4),:)]);


end;
 






