%VIS5D - interface to Vis5D files
%
%  [INFO]=VIS5D('open','filename');
%  opens and returns information on the file and its variables
%
%  [INFO]=VIS5D('info'); 
%  returns info on the open file and its variables
%
%  [NAME]=VIS5D('file'); 
%  returns the filename of the open file
%
%  VIS5D('close');
%  closes the currently open file
%
%  The structure of the INFO return array is as follows
%  filename   = The file's name as given by the user
%  xydims     = 1x2 matrix of number of columns and rows
%  ntimes     = number of time steps in file
%  xaxis      = values along the x axis
%  yaxis      = values along the y axis
%  times      = 1xntimes time/date stamps in the DATESTR format
%  xyzunits   = struct for the units of axes
%  -->      x = x axis units
%  -->      y = y axis units
%  -->      z = z axis units
%  nvars      = number of variables in Vis5D file
%  vars       = 1xNumVars array of structs describing variables
%  -->   name = the name of the variable
%  -->  units = the units for this variable
%  --> limits = 1x2 matrix of the min and max values for this variable
%  -->   zdim = number of levels for this variable
%  -->  zaxis = 1xzdim matrix of the values along the z axis
%
%  Primitive Vis5D-mex data functions include V5DPOINT, V5DXYSLICE, V5DXZSLICE,
%  V5DYZSLICE, V5DVOL, V5DXPROFILE, V5DYPROFILE, V5DZPROFILE, and V5DTPROFILE.
%  These operate only by returning data from the file currently
%  open from a VIS5D('open') call.
%  Tools are defined as those which operate using the data or the returned
%  INFO structure.
%  NOTE: primatives return with axis ordering (X,Y), and not (Y,X) as is
%  standard in matrices.
%
%  See also: V5DPOINT, V5DXYSLICE, V5DXZSLICE, V5DYZSLICE, V5DARBZSLICE, V5DVOL,
%            V5DXPROFILE, V5DYPROFILE, V5DZPROFILE, V5DTPROFILE,
%            V5D_DEG_TO_KM, V5DAVEXPROFILE, V5DAVEZPROFILE, V5DPLOTXYSLICE,
%            V5DPLOTXZSLICE, V5DGETVARNUM, V5DLOCATE, V5DPRINTVARS

% ADDITIONAL DOCUMENTATION ON THE VIS5D.MEX interface
%
% The most primative function for matrix retrieval is 
% VIS5D(nVARIABLE, nX, nY, nZ, nT)
% any axis variable can be specified as [] (null) to signify all
% on that axis.  the nVARIABLE cannot do this, as it is impractical
% to store potentially varying grid sizes in one standard grid.

% vis5d-mex Version 0.13
% part of the Vis5D-Matlab Toolkit
%
% (c) Joseph Garcia, 2000, 2001 <jpgarcia@lidar.ssec.wisc.edu>
% University of Wisconsin Lidar Group
% Space Science and Engineering Center
% Madison, WI, USA
